@@ -4,12 +4,13 @@ package Chart::GGPlot;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Data::Munge qw(elem);
 use Data::Frame::Types qw(DataFrame);
 use Data::Frame::Util qw(guess_and_convert_to_pdl);
 use Module::Load;
+use Types::PDL qw(Piddle1D PiddleFromAny);
 use Types::Standard qw(Maybe Str);
 
 use Chart::GGPlot::Plot;
@@ -46,16 +47,19 @@ sub ggplot {
 }
 
 
+# Do not check :$x, :$y's types here as we would like to allow coercion
+# from arrayref to piddle.
 fun qplot (
     :$x, :$y, 
     :$facets = undef,
     Str :$geom = "auto",
     :$xlim = undef, :$ylim = undef,
     :$title = undef, :$xlab = 'x', :$ylab = 'y',
-#    : $log     = "",
-#    : $asp     = undef,
     %rest
   ) {
+    # Can't do :$log in func params as it would conflict with $log
+    # from Log::Any.
+    my $log_mode = $rest{log} // '';
 
     my $all_aesthetics = Chart::GGPlot::Aes->all_aesthetics;
 
@@ -96,30 +100,17 @@ fun qplot (
         die "'facets' is not yet supported.";
     }
 
+    my $geom_func = $geom eq 'auto' ? 'geom_point' : "geom_${geom}";
+    $p->$geom_func();
+
+    if ( $log_mode =~ /x/ ) { $p->scale_x_log10(); }
+    if ( $log_mode =~ /y/ ) { $p->scale_y_log10(); }
+
     $p->ggtitle($title) if ( defined $title );
     $p->xlab($xlab)     if ( defined $xlab );
     $p->ylab($ylab)     if ( defined $ylab );
-
-    my $geom_func;
-    if ( $geom eq 'auto' ) {
-        $geom_func = 'geom_point';
-    }
-    else {
-        $geom_func = "geom_${geom}";
-    }
-
-    $p->$geom_func();
-
-    #    my $logv = fun($var) { index( $log, $var ) >= 0 };
-    #
-    #    if ( $logv->('x') ) { $p = $p + scale_x_log10(); }
-    #    if ( $logv->('y') ) { $p = $p + scale_y_log10(); }
-    #
-    #    if ( defined $asp ) { $p = $p + theme( aspect_ratio = $asp ); }
-    #    if ( defined $xlab ) { $p = $p + xlim($xlab); }
-    #    if ( defined $ylab ) { $p = $p + ylim($ylab); }
-    #    if ( defined $xlim ) { $p = $p + xlim($xlim); }
-    #    if ( defined $ylim ) { $p = $p + ylim($ylim); }
+    $p->xlim($xlim)     if ( defined $xlim );
+    $p->ylim($ylim)     if ( defined $ylim );
 
     return $p;
 }
@@ -138,22 +129,39 @@ Chart::GGPlot - ggplot2 port in Perl
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 STATUS
 
-At this moment this library is still under active development (at my
-after-work time) and is highly incomplete. Basically only what's in the
-C<examples> directory is able to work now. And its API can change
-without notice.
+At this moment this library is experimental and still under active
+development (at my after-work time). It's still quite incomplete compared
+to R's ggplot2 library, but the core features are working.
 
 Besides, it heavily depends on my L<Alt::Data::Frame::ButMore> library,
 which is also experimental.
 
+=head1 SYNOPSIS
+
+    use Chart::GGPlot qw(:all);
+    use Data::Frame::Examples qw(mtcars);
+
+    my $plot = ggplot(
+        data => mtcars(),
+        mapping => aes( x => 'wt', y => 'mpg' )
+    )->geom_point();
+
+    # show in browser
+    $plot->show;
+
+    # export to image file
+    $plot->save('mtcars.png');
+
+    # see "examples" dir of this library's distribution for more examples.
+
 =head1 DESCRIPTION
 
 This Chart-GGPlot library is an implementation of
-L<ggplot|https://en.wikipedia.org/wiki/Ggplot> in Perl. It's designed to
+L<ggplot2|https://en.wikipedia.org/wiki/Ggplot2> in Perl. It's designed to
 be possible to support multiple plotting backends. And it ships a default
 backend which uses L<Chart::Plotly>.
 
@@ -163,12 +171,15 @@ library.
 Example exported image files:
 
 =for html <p float="left">
-<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/position_stack_02_02.png" alt="proportional stacked bar" width="45%">
-<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/geom_line_02_01.png" alt="line chart" width="45%">
-<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/scale_viridis_02_01.png" alt="viridis color scale" width="45%">
-<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/theme_01_06.png" alt="theme 'minimal'" width="45%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/position_stack_02_02.png" alt="proportional stacked bar" width="40%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/geom_line_02_01.png" alt="line chart" width="40%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/geom_boxplot_01_02.png" alt="boxplot" width="40%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/scale_viridis_02_01.png" alt="viridis color scale" width="40%">
+<img src="https://raw.githubusercontent.com/stphnlyd/perl5-Chart-GGPlot/master/examples/theme_01_06.png" alt="theme 'minimal'" width="40%">
 </p>
 
+See the C<examples> dir in the library's distribution for more examples.
+
 =head1 FUNCTIONS
 
 =head2 ggplot
@@ -180,11 +191,10 @@ See L<Chart::GGPlot::Plot> for details.
 
 =head2 qplot
 
-    qplot(:$x, :$y,
-          Str :$geom='auto',
-          :$xlim=undef, :$ylim=undef,
-          :$title=undef, :$xlab='x', :$ylab='y',
-          %rest)
+    qplot(Piddle1D :$x, Piddle1D :$y, Str :$geom='auto',
+        :$xlim=undef, :$ylim=undef,
+        :$log='', :$title=undef, :$xlab='x', :$ylab='y',
+        %rest)
 
 =head1 ENVIRONMENT VARIABLES
 
@@ -194,7 +204,7 @@ A positive integer would enable debug messages.
 
 =head1 SEE ALSO
 
-L<ggplot|https://en.wikipedia.org/wiki/Ggplot>
+L<ggplot2|https://en.wikipedia.org/wiki/Ggplot2>
 
 L<Chart::GGPlot::Plot>
 
