@@ -4,7 +4,7 @@ package Chart::GGPlot::Aes::Functions;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Eval::Quosure;
 use List::AllUtils qw(pairmap);
@@ -76,7 +76,7 @@ fun is_position_aes ($aes_names) {
     return ( List::AllUtils::all { $_ eq 'x' or $_ eq 'y' } @$new_names );
 }
 
-# Given a character vector, create a set of identity mappings
+
 fun aes_all (@names) {
     return _aes( { map { $_ => $_ } @names }, $aes_level_default );
 }
@@ -95,26 +95,45 @@ Chart::GGPlot::Aes::Functions - Function interface for aesthetics mappings
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
+
+=head1 METHODS
+
+=head2 aes_all
+
+    aes_all(@aes_names)
+
+Given a array of aes names, create a set of identity mappings, that is
+like C<aes(x =E<gt> 'x', y =E<gt> 'y', ...)>.
 
 =head1 FUNCTIONS
 
 =head2 aes
 
-    my $aes = aes(%aesthetics_mapping);
+    aes(%aesthetics_mapping);
 
-This function is not equivalent to C<Chart::GGPlot::Aes-E<gt>new()>. This
+This function is not exactly same as C<Chart::GGPlot::Aes-E<gt>new()>. This
 function is specifically for creating aesthetics mapping which specifies
 the mapping from data to aesthetics. Returned aes object from this function
-is usually used for the C<mapping> attr of C<Chart::GGPlot> objects or
-C<Chart::GGPlot::Geom> consumers.
+is usually used for the C<mapping> attr of C<Chart::GGPlot::Plot> objects or
+C<Chart::GGPlot::Geom> objects.
 
 Values of C<%aesthetics_mapping> need to be one of the following:
-=for :list
-* An C<Eval::Quosure> object.
-* Anything else would be stringified and converted to an C<Eval::Quosure>
+
+=over 4
+
+=item *
+
+An C<Eval::Quosure> object.
+
+=item *
+
+Anything else would be stringified and converted to an C<Eval::Quosure>
+
 object with enviroment be caller of the C<aes()> function.
 
+=back
+
 =head1 SEE ALSO
 
 L<Chart::GGPlot::Aes>, L<Eval::Quosure>
