@@ -5,11 +5,11 @@ package Chart::GGPlot::Backend::Plotly;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Backend);
 
-use Chart::Plotly 0.023 qw(show_plot);
+use Chart::Plotly 0.025 qw(show_plot);
 use Chart::Plotly::Plot;
 use Chart::Plotly::Image::Orca;
 
@@ -32,7 +32,7 @@ classmethod _split_on($data) {
     return [];
 }
 
-method layer_to_traces ($layer, $data, $layout, $plot) {
+method layer_to_traces ($layer, $data, $prestats_data, $layout, $plot) {
     return if ( $data->isempty );
 
     my $geom            = $layer->geom;
@@ -44,7 +44,7 @@ method layer_to_traces ($layer, $data, $layout, $plot) {
     my $geom_params = $layer->geom_params;
     my $stat_params = $layer->stat_params;
     my $aes_params  = $layer->aes_params;
-    my $param = $geom_params->merge($stat_params)->merge($aes_params);
+    my $params = $geom_params->merge($stat_params)->merge($aes_params);
 
     my $coord  = $layout->coord;
 
@@ -99,8 +99,6 @@ method layer_to_traces ($layer, $data, $layout, $plot) {
         my $hovertext = $class_geom_impl->make_hovertext($d, \@hover_labels);
         $d->set( 'hovertext', PDL::SV->new($hovertext) );
 
-        #my $na_rm = $params->at('na_rm') // false;
-
         my @splitted_sorted;
         if ( $split_vars->length ) {
             my $fac = do {
@@ -127,7 +125,7 @@ method layer_to_traces ($layer, $data, $layout, $plot) {
             sub {
                 my ($d) = @_;
 
-                my $trace = $class_geom_impl->to_trace($d);
+                my $trace = $class_geom_impl->to_trace($d, $params);
 
                 # If we need a legend, set legend info.
                 my $show_legend =
@@ -153,20 +151,28 @@ method layer_to_traces ($layer, $data, $layout, $plot) {
         );
     };
 
-    my $splitted = $data->split( $data->at('PANEL') );
+    my $splitted_data = $data->split( $data->at('PANEL') );
+    my $splitted_prestats_data =
+      $prestats_data->split( $prestats_data->at('PANEL') );
     return [
         pairmap {
-            my ( $panel_idx, $data ) = ( $a, $b );
+            my ( $panel_id, $panel_data ) = ( $a, $b );
 
-            my $panel_params = $layout->panel_params->at($panel_idx);
-            $panel_to_traces->( $data, $panel_params );
+            my $panel_prestats_data = $splitted_prestats_data->{$panel_id};
+            $panel_to_traces->(
+                $class_geom_impl->to_basic(
+                    $panel_data, $panel_prestats_data, $layout,
+                    $params,     $plot
+                ),
+                $layout->panel_params->at($panel_id)
+            );
         }
-        %$splitted
+        %$splitted_data
     ];
 }
 
 
-method to_plotly ($plot_built) {
+method _to_plotly ($plot_built) {
     my $plot   = $plot_built->plot;
     my $layers = $plot->layers;
     my $layout = $plot_built->layout;
@@ -230,7 +236,21 @@ method to_plotly ($plot_built) {
         my $axis_title = $sc->name // $labels->at($xy) // '';
 
         my $range = $panel_params->{"$xy.range"}->unpdl;
-        my $labels = $panel_params->{"$xy.labels"}->as_pdlsv->unpdl;
+        my $labels = $panel_params->{"$xy.labels"}->as_pdlsv;
+
+        # TODO: fix this in Data::Frame's PDL patch
+        unless ( $labels->DOES('PDL::SV') and $labels->type >= PDL::float ) {
+            $labels = PDL::SV->new(
+                [
+                    map {
+                        my $s = sprintf( $PDL::doubleformat, $_ );
+                        $s =~ s/^\s*//gr;
+                    } @{ $labels->unpdl }
+                ]
+            );
+        }
+        $labels = $labels->unpdl;
+
         my $major_source = $panel_params->{"$xy.major_source"}->unpdl;
         my %ticks = pairwise { $a => $b } @$major_source, @$labels;
 
@@ -316,12 +336,14 @@ method to_plotly ($plot_built) {
 
     for my $i ( 0 .. $#$layers ) {
         my $layer = $layers->[$i];
-        my $data  = $plot_built->data->[$i];
+        my $data  = $plot_built->layer_data($i);
+        my $prestats_data  = $plot_built->layer_prestats_data($i);
 
         $log->debug( "data at layer $i:\n" . $data->string ) if $log->is_debug;
 
         my $panels_traces =
-          $self->layer_to_traces( $layer, $data, $layout, $plot );
+          $self->layer_to_traces( $layer, $data, $prestats_data,
+            $layout, $plot );
         for my $panel (@$panels_traces) {
             for my $trace (@$panel) {
                 $plotly->add_trace($trace);
@@ -398,7 +420,7 @@ method to_plotly ($plot_built) {
 
 method ggplotly ($ggplot) {
     my $plot_built = $self->build($ggplot);
-    return $self->to_plotly($plot_built);
+    return $self->_to_plotly($plot_built);
 }
 
 method show ($ggplot, HashRef $opts={}) {
@@ -433,7 +455,7 @@ Chart::GGPlot::Backend::Plotly - Plotly backend for Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 DESCRIPTION
 
@@ -441,19 +463,21 @@ The Plotly backend for Chart::GGPlot.
 
 =head1 METHODS
 
-=head2 to_plotly
+=head2 ggplotly
 
-Returns a Chart::GPlotly object.
+    ggplotly($ggplot)
+
+Returns a L<Chart::Plotly> object.
 
 =head2 show
 
-    $backend->show($ggplot, HashRef $opts={});
+    show($ggplot, HashRef $opts={})
 
 Show the plot like in web browser.
 
 =head2 save
 
-    $backend->save($ggplot, $filename, HashRef $opts={});
+    save($ggplot, $filename, HashRef $opts={})
 
 Export the plot to a static image file.
 
