@@ -4,9 +4,10 @@ package Chart::GGPlot::Backend::Plotly::Geom;
 
 use Chart::GGPlot::Role;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use List::AllUtils qw(pairmap);
+use Types::Standard qw(ArrayRef);
 
 use Chart::GGPlot::Backend::Plotly::Util qw(br);
 
@@ -21,7 +22,7 @@ method use_webgl ($df) {
 requires 'to_trace';
 
 
-classmethod make_hovertext ($df, $hover_labels) {
+classmethod make_hovertext ($df, ArrayRef $hover_labels) {
     my %seen_hover_aes;
     my @hover_assoc = pairmap {
         my ( $aes, $var ) = ( $a, $b );
@@ -53,6 +54,10 @@ classmethod _hovertext_data_for_aes ($df, $aes) {
     );
 }
 
+classmethod to_basic($data, $prestats_data, $layout, $params, $plot) {
+    return $data;
+}
+
 1;
 
 __END__
@@ -67,7 +72,7 @@ Chart::GGPlot::Backend::Plotly::Geom - Role for geom-specific details with the P
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 METHODS
 
@@ -75,21 +80,29 @@ version 0.0000_02
 
     use_webgl($df)
 
-Returns a boolean value for whether or not to use webgl, like for scatter plots.
-Now it decides by comparing the data count in C<$df> against module variable
-C<$WEBGL_THRESHOLD>. The variable can be adjusted by like,
+Returns a boolean value for whether or not to use webgl, like for scatter
+plots where Plotly is very slow to generate SVG when the data count is large.
+Now it decides by comparing the data count in C<$df> against variable
+C<$Chart::GGPlot::Backend::Plotly::WEBGL_THRESHOLD>.
+The variable can be adjusted by like,
 
     $Chart::GGPlot::Backend::Plotly::WEBGL_THRESHOLD = 2000;
 
 =head2 to_trace
 
-    to_trace($df, %rest)
+    to_trace($df, $params, @rest)
 
 This shall be implemented by consumers of this role.
+It should return an arrayref of Chart::Plotly::Trace::X objects.  
 
 =head2 make_hovertext
 
-    make_hovertext($df, $aes_names)
+    make_hovertext($df, ArrayRef $hover_labels)
+
+This method is called by L<Chart::GGPlot::Backend::Plotly> for preparing
+Plotly hovertext.
+C<$hover_labels> is an associative arrayref that maps aes names to hover
+text labels.
 
 =head1 SEE ALSO
 
