@@ -1,14 +1,14 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Blank;
 
-# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Bar 
+# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Blank
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
-classmethod to_trace ($df, %rest) { }
+classmethod to_trace ($df, $params, @rest) { }
 
 __PACKAGE__->meta->make_immutable;
 
@@ -22,15 +22,16 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Blank - Chart::GGPlot's Plotly support for Geom::Bar 
+Chart::GGPlot::Backend::Plotly::Geom::Blank - Chart::GGPlot's Plotly support for Geom::Blank
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 SEE ALSO
 
-L<Chart::GGPlot::Backend::Plotly::Geom>
+L<Chart::GGPlot::Backend::Plotly::Geom>,
+L<Chart::GGPlot::Geom::Blank>
 
 =head1 AUTHOR
 
