@@ -4,7 +4,7 @@ package Chart::GGPlot::Backend::Plotly::Geom::Line;
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 extends qw(Chart::GGPlot::Backend::Plotly::Geom::Path);
 
@@ -24,11 +24,12 @@ Chart::GGPlot::Backend::Plotly::Geom::Line - Chart::GGPlot's Plotly support for
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 SEE ALSO
 
-L<Chart::GGPlot::Backend::Plotly::Geom>
+L<Chart::GGPlot::Backend::Plotly::Geom>,
+L<Chart::GGPlot::Geom::Line>
 
 =head1 AUTHOR
 
