@@ -1,27 +1,29 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Path;
 
-# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Bar
+# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Path
 
 use Chart::GGPlot::Class qw(:pdl);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
 use Module::Load;
 
-use Chart::GGPlot::Backend::Plotly::Util qw(cex_to_px to_rgb group_to_NA);
+use Chart::GGPlot::Backend::Plotly::Util qw(
+  cex_to_px to_rgb group_to_NA pdl_to_plotly
+);
 use Chart::GGPlot::Util qw(ifelse);
 
 sub mode {
     return 'lines';
 }
 
-classmethod marker ($df, %rest) {
+classmethod marker ($df, @rest) {
     return;
 }
 
-classmethod to_trace ($df, %rest) {
+classmethod to_trace ($df, $params, @rest) {
     $df = group_to_NA($df);
 
     my $use_webgl = $class->use_webgl($df);
@@ -37,7 +39,7 @@ classmethod to_trace ($df, %rest) {
     }
 
     my ( $x, $y ) = map { $df->at($_) } qw(x y);
-    my $marker = $class->marker( $df, %rest );
+    my $marker = $class->marker( $df, $params, @rest );
 
     my $mode = $class->mode;
     my $line;
@@ -61,8 +63,8 @@ classmethod to_trace ($df, %rest) {
     }
 
     return $plotly_trace_class->new(
-        x    => $x->unpdl,
-        y    => $y->unpdl,
+        x    => $x,
+        y    => $y,
         mode => $mode,
         maybe
           line => $line,
@@ -75,7 +77,7 @@ classmethod to_trace ($df, %rest) {
             $use_webgl
             ? ()
             : (
-                hovertext => $df->at('hovertext')->unpdl,
+                hovertext => pdl_to_plotly( $df->at('hovertext') ),
                 hoverinfo => 'text',
             )
         ),
@@ -94,15 +96,16 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Path - Chart::GGPlot's Plotly support for Geom::Bar
+Chart::GGPlot::Backend::Plotly::Geom::Path - Chart::GGPlot's Plotly support for Geom::Path
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 SEE ALSO
 
-L<Chart::GGPlot::Backend::Plotly::Geom>
+L<Chart::GGPlot::Backend::Plotly::Geom>,
+L<Chart::GGPlot::Geom::Path>
 
 =head1 AUTHOR
 
