@@ -8,7 +8,7 @@ use MooseX::Singleton;
 
 extends qw(Chart::GGPlot::Geom::Rect);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Chart::GGPlot::Aes;
 use Chart::GGPlot::Util qw(:all);
@@ -49,7 +49,11 @@ Chart::GGPlot::Geom::Bar - Class for bar geom
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
+
+=head1 SEE ALSO
+
+L<Chart::GGPlot::Geom>
 
 =head1 AUTHOR
 
