@@ -1,4 +1,4 @@
-package Chart::GGPLot::Geom::Blank;
+package Chart::GGPlot::Geom::Blank;
 
 # ABSTRACT: Class for blank geom
 
@@ -6,7 +6,7 @@ use Chart::GGPlot::Class;
 use namespace::autoclean;
 use MooseX::Singleton;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 with qw(Chart::GGPlot::Geom);
 
@@ -24,11 +24,15 @@ __END__
 
 =head1 NAME
 
-Chart::GGPLot::Geom::Blank - Class for blank geom
+Chart::GGPlot::Geom::Blank - Class for blank geom
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
+
+=head1 SEE ALSO
+
+L<Chart::GGPlot::Geom>
 
 =head1 AUTHOR
 
