@@ -4,7 +4,9 @@ package Chart::GGPlot::Geom::Functions;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
+
+use Module::Load;
 
 use Chart::GGPlot::Layer::Functions qw(layer);
 use Chart::GGPlot::Types;
@@ -19,15 +21,6 @@ my @export_ggplot = qw(
   geom_bar geom_histogram
 );
 
-our @EXPORT_OK = (
-    @export_ggplot,
-);
-
-our %EXPORT_TAGS = (
-    all    => \@EXPORT_OK,
-    ggplot => \@export_ggplot,
-);
-
 fun geom_blank (:$mapping = undef, :$data = undef,
                 :$stat = "identity", :$position = "identity",
                 :$show_legend = 'auto', :$inherit_aes = true,
@@ -99,6 +92,7 @@ fun geom_point (:$mapping = undef, :$data = undef,
     );
 }
 
+
 fun geom_bar(:$mapping = undef, :$data = undef,
              :$stat = 'count', :$position = 'stack', 
              :$width = undef, :$na_rm = false,
@@ -120,6 +114,7 @@ fun geom_bar(:$mapping = undef, :$data = undef,
     );
 }
 
+
 fun geom_histogram (:$data = undef, :$mapping = undef,
                     :$stat = "bin", :$position = "stack",
                     :$binwidth = undef, :$bins = undef,
@@ -144,6 +139,28 @@ fun geom_histogram (:$data = undef, :$mapping = undef,
     );
 }
 
+my @geom_namespaces = qw(Boxplot);
+
+for my $partial_ns (@geom_namespaces) {
+    my $package = "Chart::GGPlot::Geom::$partial_ns";
+    load $package;
+
+    my $func_name = "geom_" . lc($partial_ns);
+    no strict 'refs';
+    *{$func_name} = $package->ggplot_function;
+    push @export_ggplot, $func_name;
+}
+
+our @EXPORT_OK = (
+    @export_ggplot,
+);
+
+our %EXPORT_TAGS = (
+    all    => \@EXPORT_OK,
+    ggplot => \@export_ggplot,
+);
+
+
 1;
 
 __END__
@@ -158,37 +175,75 @@ Chart::GGPlot::Geom::Functions - Function interface for Chart::GGPlot::Geom
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
-=head1 METHODS
+=head1 DESCRIPTION
+
+This module provides the C<geom_*> functions supported by this Chart-GGPlot
+library.  When used standalone, each C<geom_*> function generates a
+L<Chart::GGPlot::Layer> object. Also the functions can be used as
+L<Chart::GGPlot::Plot> methods, to add layers into the plot object.
+
+=head1 FUNCTIONS
 
 =head2 geom_path
 
-    geom_path (:$mapping = undef, :$data = undef, 
-               :$stat = 'identity', :$position = 'identity', 
-               :$na_rm = false,
-               :$show_legend = 'auto', :$inherit_aes = true, 
-               %rest)
+    geom_path(:$mapping = undef, :$data = undef, :$stat = 'identity',
+        :$position = 'identity', :$na_rm = false, :$show_legend = 'auto',
+        :$inherit_aes = true, 
+        %rest)
 
-C<geom_path()> connects the observations in the order in which they appear in
-the data. 
+The "path" geom connects the observations in the order in which they appear
+in the data. 
 
 =head2 geom_line
 
-    geom_line (:$mapping = undef, :$data = undef, 
-               :$stat = 'identity', :$position = 'identity', 
-               :$na_rm = false,
-               :$show_legend = 'auto', :$inherit_aes = true, 
-               %rest)
+    geom_line(:$mapping = undef, :$data = undef, :$stat = 'identity',
+        :$position = 'identity', :$na_rm = false, :$show_legend = 'auto',           :$inherit_aes = true, 
+        %rest)
 
-C<geom_line()> connects the observations in the order of the variable on the
-x axis. 
+The "line" geom connects the observations in the order of the variable on
+the x axis. 
 
 =head2 geom_point
 
+    geom_point(:$mapping = undef, :$data = undef, :$stat = 'identity',
+        :$position = 'identity', :$na_rm = false, :$show_legend = 'auto',
+        :$inherit_aes = true, %rest)
+
+The "point" geom is used to create scatterplots.
+The scatterplot is most useful for displaying the relationship between two
+continuous variables.
+A bubblechart is a scatterplot with a third variable mapped to the size of
+points.
+
+=head2 geom_bar
+
+    geom_bar(:$mapping = undef, :$data = undef, :$stat = 'count',
+        :$position = 'stack', :$width = undef,
+        :$na_rm = false, :$show_legend = 'auto', :$inherit_aes = true,
+        %rest)
+
+The "bar" geom makes the height bar proportional to the number of cases in each group (or if the C<weight> aesthetic is supplied, the sum of the
+C<weights>). 
+It uses C<stat_count()> by default: it counts the number of cases at each x
+position. 
+
+=head2 geom_histogram
+
+    geom_histogram(:$data = undef, :$mapping = undef, :$stat = "bin",
+        :$position = "stack", :$binwidth = undef, :$bins = undef,
+        :$na_rm = false, :$show_legend = 'auto', :$inherit_aes = true,
+        %rest)
+
+Visualise the distribution of a single continuous variable by dividing the
+x axis into bins and counting the number of observations in each bin.
+This "histogram" geom displays the counts with bars.
+
 =head1 SEE ALSO
 
-L<Chart::GGPlot::Geom>
+L<Chart::GGPlot::Layer>,
+L<Chart::GGPlot::Plot>
 
 =head1 AUTHOR
 
