@@ -1,13 +1,13 @@
 package Chart::GGPlot::Geom::Line;
 
-# ABSTRACT: Class for path geom
+# ABSTRACT: Class for line geom
 
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
 extends qw(Chart::GGPlot::Geom::Path);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 method setup_data ($data, $params) {
     return $data->sort( [qw(PANEL group x)] );
@@ -25,11 +25,15 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Geom::Line - Class for path geom
+Chart::GGPlot::Geom::Line - Class for line geom
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
+
+=head1 SEE ALSO
+
+L<Chart::GGPlot::Geom>
 
 =head1 AUTHOR
 
