@@ -6,7 +6,7 @@ use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 use MooseX::Singleton;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use List::AllUtils qw(reduce);
 use PDL::Primitive qw(which);
@@ -106,7 +106,11 @@ Chart::GGPlot::Geom::Path - Class for path geom
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
+
+=head1 SEE ALSO
+
+L<Chart::GGPlot::Geom>
 
 =head1 AUTHOR
 
