@@ -6,7 +6,7 @@ use Chart::GGPlot::Class;
 use namespace::autoclean;
 use MooseX::Singleton;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Module::Load;
 use Types::Standard qw(ConsumerOf InstanceOf);
@@ -51,7 +51,7 @@ Chart::GGPlot::Global - Various global variables and settings
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 SYNOPSIS
 
@@ -63,17 +63,19 @@ version 0.0000_02
 =head1 DESCRIPTION
 
 This is a singleton class that holds various global variables and settings
-for Chart::GGPlot.
+for the Chart::GGPlot system.
 
 =head1 ATTRIBUTES
 
 =head2 theme_current
 
-The current theme.
+RW. The current theme.
+L<Chart::GGPlot::Theme> object.
 
 =head2 element_tree
 
-Element tree for the theme elements.
+RW. Element tree for the theme elements.
+L<Chart::GGPlot::Theme::ElementTree> object.
 
 =head1 AUTHOR
 
