@@ -4,7 +4,7 @@ package Chart::GGPlot::Guide::Functions;
 
 use Chart::GGPlot::Setup;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Chart::GGPlot::Guide::Legend;
 
@@ -18,6 +18,7 @@ our %EXPORT_TAGS = (
     'ggplot' => [qw(guide_legend)],
 );
 
+
 sub guide_legend {
     return Chart::GGPlot::Guide::Legend->new(@_);   
 }
@@ -37,7 +38,13 @@ Chart::GGPlot::Guide::Functions - Function interface for guides
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
+
+=head1 FUNCTIONS
+
+=head2 guide_legend
+
+    guide_legend(:$title=undef, %rest)
 
 =head1 SEE ALSO
 
