@@ -5,7 +5,7 @@ package Chart::GGPlot::Layer;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use List::AllUtils qw(pairgrep pairkeys pairmap);
 use Module::Load;
@@ -149,7 +149,6 @@ method string () {
     return $s;
 }
 
-
 method layer_data ($plot_data) {
     return $plot_data unless ( defined $self->data );
 
@@ -223,14 +222,11 @@ method map_statistic ( $data, $plot ) {
     #$aesthetics = compact($aesthetics);
 
     my $new = $aesthetics->hslice( $self->calculated_aes($aesthetics) );
-    #say Dumper($new->keys);
     return $data if ( $new->isempty );
 
     my $stat_data =
       Data::Frame->new(
         columns => [ pairmap { $a => $data->eval_tidy($b) } $new->flatten ] );
-    #say $stat_data->string;
-
     $plot->scales->add_defaults( $data, $new );
 
     # Transform the values, if the scale say it's ok
@@ -324,40 +320,53 @@ Chart::GGPlot::Layer - Chart::GGPlot layer
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 DESCRIPTION
 
 A layer is a combination of data, stat and geom with a potential position
-adjustment. Usually layers are created using `geom_*` or `stat_*`
+adjustment. Usually layers are created using C<geom_*> or C<stat_*>
 calls but it can also be created directly using this class.
 
 =head1 ATTRIBUTES
 
+=head2 data
+
+The data to be displayed in this layer.
+If C<undef>, the default, the data is inherited from the plot data as
+specified in the call to C<ggplot()>.
+
+=head2 mapping
+
+Set of aesthetic mappings created by C<aes()>.
+If specified and C<inherit_aes> is true (the default), it's combined with
+the default mapping at the top level of the plot.
+You must supply this attribute if there no plot mapping.
+
 =head2 geom
 
-The geometric object to display the data.
+The geometric object to use display the data.
 
 =head2 stat
 
-The statistical transformation to use on the data for this
-layer, as a string.
+The statistical transformation to use on the data for this layer, as a
+string.
 
 =head2 position
 
-Position adjustment, either as a string, or the result of
-a call to a position adjust function.
+Position adjustment, either as a string, or the result of a call to a
+position adjust function.
 
 =head2 inherit_aes
 
-If `false`, overrides the default aesthetics,
-rather than combining with them. This is most useful for helper functions
-that define both data and aesthetics and shouldn't inherit behaviour from
-the default plot specification, e.g. [borders()].
+If false, overrides the default aesthetics, rather than combining with them.
+This is most useful for helper functions that define both data and
+aesthetics and shouldn't inherit behaviour from the default plot
+specification.
 
 =head2 params
 
-Additional parameters to the `geom` and `stat`.
+Additional parameters to the "geom" and "stat".
 
 =head2 show_legend
 
@@ -387,8 +396,6 @@ A Chart::GGPlot::Aes object, to finely select the aesthetics to display.
 
 =head2 string()
 
-=head2 layer_data($plot_data)
-
 =head1 AUTHOR
 
 Stephan Loyd <sloyd@cpan.org>
