@@ -4,14 +4,14 @@ package Chart::GGPlot::Layer::Functions;
 
 use Chart::GGPlot::Setup;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Chart::GGPlot::Util qw(:all);
 
 use Chart::GGPlot::Layer;
 use Chart::GGPlot::Aes::Functions qw(aes);
 
-use Exporter qw(import);
+use parent qw(Exporter::Tiny);
 
 my @export_ggplot = qw(layer);
 
@@ -40,7 +40,7 @@ Chart::GGPlot::Layer::Functions - Layer functions
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 FUNCTIONS
 
