@@ -5,7 +5,7 @@ package Chart::GGPlot::Layout;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Data::Frame::Types qw(DataFrame);
 use Data::Munge qw(elem);
@@ -239,16 +239,7 @@ classmethod scale_apply ($data, $vars, $method,
                 $pieces = $pieces->[0]->glue( 0, @$pieces[ 1 .. $#$pieces ] );
 
                 # Join pieces back together, if necessary
-
-                # Normally for a continuous scale, it gets only a pdl of
-                #  length 2. But below it would create a pdl of full length
-                #  of $data->nrow. We pad with bad values.
                 if ( $pieces->length ) {
-                    my $indices = $scale_indices_flattened->copy;
-                    $indices->slice(
-                        pdl( [ $pieces->length .. $indices->length - 1 ] ) ) .=
-                      'nan';
-                    $indices->setnantobad;
                     return ( $var => $pieces->slice($scale_indices_flattened) );
                 }
                 else {
@@ -273,7 +264,7 @@ Chart::GGPlot::Layout - Layout
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 DESCRIPTION
 
@@ -300,10 +291,12 @@ The individual position scales for each panel
 =head2 coord
 
 The coordinate system.
+Default is the output of C<coord_cartesian()>
 
 =head2 facet
 
 The facetting specification.
+Default is the output of C<facet_null()>
 
 =head1 METHODS
 
