@@ -4,7 +4,7 @@ package Chart::GGPlot::Limits;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Data::Frame;
 use List::AllUtils qw(pairmap); 
@@ -120,7 +120,7 @@ Chart::GGPlot::Limits - Functions for applying limits to the scales
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 SYNOPSIS
 
@@ -142,37 +142,47 @@ version 0.0000_02
 
 =head1 DESCRIPTION
 
-By default, any values outside limits will be treated as C<NA> and
-are thus not plotted.
+The module provides some functions for specifying limits of a plot.
+By default, any values outside limits will be not plottted.
 
 =head1 FUNCTIONS
 
-=head2 lims(%pairs)
+=head2 lims
+
+    lims(%pairs)
 
 Call C<limits()> on each kv pair in C<%pairs>.
 Returns an array ref like C<[ limits($key1, $value1), ... ]>.
 
-=head2 xlim($a, $b)
+=head2 xlim
+
+    xlim($a, $b)
 
 This is a shortcut of 
 
     limits(x => [$a, $b]);
 
-=head2 ylim($a, $b)
+=head2 ylim
+
+    ylim($a, $b)
 
 This is a shortcut of 
 
     limits(y => [$a, $b]);
 
-=head2 limits($var, $v)
+=head2 limits
 
-=head2 expand_limits(%params)
+    limits($var, $lims)
+
+=head2 expand_limits
+
+    expand_limits(%params)
 
 Expand the plot limits, using data.
 
     my $p = ggplot($mtcars, aes( x=> 'mpg', y => 'wt')) + geom_point();
-    $p += expand_limits(x => 0);
-    $p += expand_limits(y => [1, 9]);
+    $p->expand_limits(x => 0);
+    $p->expand_limits(y => [1, 9]);
 
 =head1 AUTHOR
 
