@@ -4,14 +4,14 @@ package Chart::GGPlot::Params;
 
 use Chart::GGPlot::Setup;
 use Function::Parameters qw(classmethod);
+use namespace::autoclean;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use List::AllUtils qw(pairgrep pairmap);
 use Storable qw(dclone);
 use Type::Params;
 use Types::Standard qw(HashRef);
-use namespace::autoclean;
 
 use Chart::GGPlot::Types qw(GGParams);
 
@@ -58,9 +58,12 @@ method set ( $key, $value ) {
 }
 
 
-method _at ($key) { $self->_hash->{$key}; }
+sub _at {
+    my ( $self, $key ) = @_;
+    $self->_hash->{$key};
+}
 
-method at ($key) { $self->_hash->{ $self->transform_key($key) }; }
+method at ($key) { $self->_at( $self->transform_key($key) ); }
 
 
 method flatten () {
@@ -141,13 +144,13 @@ Chart::GGPlot::Params - Collection of key-value pairs used in Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 DESCRIPTION
 
 This class provides a duck typing interface similar as
 L<Data::Frame::Autobox::HashRef>, and adds a mechanism to its
-derived classes to customize aliasing of hash keys by overriding
+derived classes to allow customize aliasing of hash keys by overriding
 the C<transform_key> classmethod.
 
 =head1 CLASS METHODS
@@ -201,6 +204,8 @@ Return a boolean value if length is 0.
 
     delete($key)
 
+Delete a key.
+
 =head2 set
 
     set($key, $value)
@@ -259,6 +264,7 @@ If C<$other> is C<undef>, returns a clone of C<$self>.
 Returns a new object.
 
     my $p2 = $p1->rename( { $from_key => $to_key, ... } );
+    my $p3 = $p1->rename( sub { my ($old_key) = @_; ... return $new_key; } );
 
 =head2 as_hashref
 
@@ -278,7 +284,8 @@ This is same as the C<copy()> method.
 
 =head1 SEE ALSO
 
-L<Data::Frame::Autobox::HashRef>
+L<Data::Frame::Autobox::HashRef>,
+L<Chart::GGPlot::Aes>
 
 =head1 AUTHOR
 
