@@ -5,7 +5,7 @@ package Chart::GGPlot::Scale::ContinuousPosition;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Types::PDL qw(Piddle PiddleFromAny);
 use Types::Standard qw(InstanceOf Maybe);
@@ -32,8 +32,8 @@ method map_to_limits ( $p, $limits = $self->get_limits ) {
     return $scaled;
 }
 
-method break_info ($range = null()) {
-    my $breaks = $self->SUPER::break_info($range);
+around break_info ($range = null()) {
+    my $breaks = $self->$orig($range);
     if ( defined $self->secondary_axis
         and not $self->secondary_axis->empty() )
     {
@@ -62,7 +62,7 @@ Chart::GGPlot::Scale::ContinuousPosition - Continuous position scale
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 AUTHOR
 
