@@ -5,7 +5,7 @@ package Chart::GGPlot::ScalesList;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Data::Munge qw(elem);
 use List::AllUtils qw(pairmap pairkeys);
@@ -18,7 +18,7 @@ use Chart::GGPlot::Types qw(:all);
 use Chart::GGPlot::Util qw(:all);
 
 
-has scales => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
+has scales => ( is => 'ro', default => sub { [] } );
 
 
 sub find {
@@ -26,9 +26,12 @@ sub find {
         ArrayRef->plus_coercions(ArrayRefFromAny) );
     my ( $self, $aesthetic ) = $check->(@_);
 
-    return PDL->pdl(
-        map { $_->aesthetics->intersect($aesthetic)->length > 0 }
-          @{ $self->scales } );
+    return pdl(
+        [
+            map { $_->aesthetics->intersect($aesthetic)->length > 0 }
+              @{ $self->scales }
+        ]
+    );
 }
 
 
@@ -55,6 +58,7 @@ method add ($scale) {
     $self->scales->push($scale);
 }
 
+
 method length () { $self->scales->length; }
 
 method input () {
@@ -68,13 +72,13 @@ method non_position_scales () {
 }
 
 
-method get_scales ($output) {
-    my $indexes = which( $self->find($output) );
+method get_scales ($aesthetic) {
+    my $indexes = which( $self->find($aesthetic) );
     return undef if ( $indexes->isempty );
     return $self->scales->at( $indexes->at(0) );
 }
 
-method isempty () { $self->scales->isempty }
+method isempty () { $self->length == 0 }
 
 
 method train_df ($df, $drop=false) {
@@ -186,34 +190,60 @@ Chart::GGPlot::ScalesList - Encapsulation multiple scale objects
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 ATTRIBUTES
 
 =head2 scales
 
-Returns an arrayref of scales object with the ScalesList object.
+Returns an arrayref of L<Chart::GGPlot::Scale> objects.
 
 =head1 METHODS
 
-=head2 find($aesthetic)
+=head2 find
 
-Returns an arrayref of indexes. 
+    find(ArrayRef $aes_names)
+    find(Str $aes_name)
 
-=head2 has_scale($aesthetic)
+Returns an arrayref of indices in the C<scales> attr, for the given
+aesthetics names.
 
-=head2 get_scales($output)
+=head2 has_scale
+
+    has_scale(ArrayRef $aes_names)
+    has_scale(Str $aes_name)
+
+=head2 length
+
+    length()
+
+Size of the C<scales> attribute.
+
+=head2 get_scales
+
+    get_scales(ArrayRef $aes_names)
+    get_scales(Str $aes_name)
 
 Returns the first scale object found.
 
-=head2 train_df($df)
+=head2 train_df
+
+    train_df($df)
 
 Train scales from a dataframe.
+Returns an arrayref of scale objects.
 
-=head2 map_df($df)
+=head2 map_df
 
-Map values from a dataframe.
-Returns a dataframe whose columns processed to map to the scales' limits.
+    map_df($df)
+
+Map values from a data frame.
+Returns a new data frame whose columns processed to map to the scales'
+limits.
+
+=head1 SEE ALSO
+
+L<Chart::GGPlot::Scale>
 
 =head1 AUTHOR
 
