@@ -5,25 +5,23 @@ package Chart::GGPlot::Setup;
 use 5.016;
 use warnings;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use utf8;
 use feature ':5.16';
 
 use Import::Into;
 
-use Alt::Data::Frame::ButMore;
-use Data::Frame;
+use Alt::Data::Frame::ButMore 0.0045;
 
 use Carp;
 use Data::Dumper ();
-use Function::Parameters 2.0;
+use Function::Parameters 2.001003;
 use Log::Any qw($log);
 use Log::Any::Adapter;
 use Safe::Isa 1.000010 ();
 use PerlX::Maybe ();
 
-#use PerlX::Assert        ();
 use Syntax::Keyword::Try ();
 use Module::Load;
 use Moose 2.1400;
@@ -33,7 +31,6 @@ use MooseX::Aliases           ();
 use MooseX::MungeHas          ();
 use MooseX::LazyRequire       ();
 use MooseX::StrictConstructor ();
-use MooseX::Traits            ();
 use boolean                   ();
 
 use List::AllUtils qw(uniq);
@@ -112,8 +109,6 @@ sub _import_tag {
         #PerlX::Assert->import::into($target);
 
         Moose::Autobox->import::into($target);
-
-        Data::Frame->import::into($target);
     }
     elsif ( $tag eq ':class' ) {
         $class->_import_tag( $target, ':base' );
@@ -126,8 +121,6 @@ sub _import_tag {
         MooseX::LazyRequire->import::into($target);
         MooseX::MungeHas->import::into($target);
         MooseX::StrictConstructor->import::into($target);
-
-        MooseX::Traits->import::into($target);
     }
     elsif ( $tag eq ':role' ) {
         $class->_import_tag( $target, ':base' );
@@ -188,7 +181,7 @@ Chart::GGPlot::Setup - Import stuffs into Chart::GGPlot classes
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 SYNOPSIS
 
