@@ -4,7 +4,9 @@ package Chart::GGPlot::Stat::Functions;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
+
+use Module::Load;
 
 use Chart::GGPlot::Layer::Functions qw(layer);
 use Chart::GGPlot::Types;
@@ -64,6 +66,17 @@ fun stat_count (:$mapping = undef, :$data = undef,
     );
 }
 
+my @stat_namespaces = qw(Boxplot);
+
+for my $partial_ns (@stat_namespaces) {
+    my $package = "Chart::GGPlot::Stat::$partial_ns";
+    load $package;
+
+    my $func_name = "stat_" . lc($partial_ns);
+    no strict 'refs';
+    *{$func_name} = $package->ggplot_function;
+}
+
 1;
 
 __END__
@@ -78,7 +91,7 @@ Chart::GGPlot::Stat::Functions - Function interface for stats
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 FUNCTIONS
 
