@@ -4,21 +4,22 @@ package Chart::GGPlot::Theme::Defaults;
 
 use Chart::GGPlot::Setup;
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Chart::GGPlot::Theme;
 use Chart::GGPlot::Theme::Element::Functions qw(:all);
 
 use parent qw(Exporter::Tiny);
 
-our @EXPORT_OK = qw(
-  theme_grey theme_bw
+my @theme_funcs = qw(
+  theme_grey theme_gray theme_bw
   theme_linedraw theme_light theme_dark
   theme_minimal theme_classic theme_void
 );
+our @EXPORT_OK   = @theme_funcs;
 our %EXPORT_TAGS = (
     all    => \@EXPORT_OK,
-    ggplot => \@EXPORT_OK,
+    ggplot => \@theme_funcs,
 );
 
 
@@ -465,7 +466,7 @@ Chart::GGPlot::Theme::Defaults - Pre-defined themes
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 SYNOPSIS
 
@@ -475,43 +476,71 @@ version 0.0000_02
 
 =head1 DESCRIPTION
 
-Some predefined themes.
+Some predefined themes for the Chart::GGPlot library.
 
 =head1 FUNCTIONS
 
 =head2 theme_grey
 
+    theme_grey(:$base_size=11, :$base_family="",
+        :$base_line_size=$base_size / 22, :$base_rect_size=$base_size / 22)
+
 The signature ggplot2 theme with a grey background and white gridlines.
 
+=head2 theme_gray
+
+This is same as the C<theme_grey()> method.
+
 =head2 theme_bw
 
+    theme_bw(:$base_size=11, :$base_family="",
+        :$base_line_size=$base_size / 22, :$base_rect_size=$base_size / 22)
+
 The classic dark-on-light ggplot2 theme.
 
 =head2 theme_linedraw
 
+    theme_linedraw(:$base_size=11, :$base_family="",
+        :$base_line_size=$base_size / 22, :$base_rect_size=$base_size / 22)
+
 A theme with only black lines of various widths on white backgrounds,
 reminiscent of a line drawings.
 
 =head2 theme_light
 
+    theme_light(:$base_size=11, :$base_family="",
+        :$base_line_size=$base_size / 22, :$base_rect_size=$base_size / 22)
+
 A theme similar to C<theme_linedraw> but with light grey lines and axes,
 to direct more attention towards the data.
 
 =head2 theme_dark
 
+    theme_dark(:$base_size=11, :$base_family="",
+        :$base_line_size=$base_size / 22, :$base_rect_size=$base_size / 22)
+
 The dark cousin of C<theme_light>, with similar line sizes but a dark
 background. Useful to make thin colored lines pop out.
 
 =head2 theme_minimal
 
+    theme_minimal(:$base_size=11, :$base_family="",
+        :$base_line_size=$base_size / 22, :$base_rect_size=$base_size / 22)
+
 A minimalistic theme with no background annotations.
 
 =head2 theme_classic
 
+    theme_classic(:$base_size=11, :$base_family="",
+        :$base_line_size=$base_size / 22, :$base_rect_size=$base_size / 22)
+
 A classic-looking theme, with x and y axis lines and no gridlines.
 
 =head2 theme_void
 
+    theme_void(:$base_size=11, :$base_family="",
+        :$base_line_size=$base_size / 22, :$base_rect_size=$base_size / 22)
+
 A completely empyt theme.
 
 =head1 SEE ALSO
