@@ -1,6 +1,6 @@
 package Chart::GGPlot::Trans;
 
-# ABSTRACT: Transformation
+# ABSTRACT: Transformation class
 
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
@@ -10,7 +10,8 @@ use Types::PDL -types;
 
 use Chart::GGPlot::Util qw(:all);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
+
 
 has name      => ( is => 'ro', isa => Str,     required => 1 );
 has transform => ( is => 'ro', isa => CodeRef, required => 1 );
@@ -55,11 +56,45 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Trans - Transformation
+Chart::GGPlot::Trans - Transformation class
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
+
+=head1 DESCRIPTION
+
+A transformation object bundles together a transform, its inverse, and methods for
+generating breaks and labels.
+
+=head1 ATTRIBUTES
+
+=head2 name
+
+Name of the transformation object.
+
+=head2 transform
+
+A coderef for the transform.
+
+=head2 inverse
+
+A coderef for inverse of the transform.
+
+=head2 breaks
+
+A coderef for generating the breaks. 
+
+=head2 minor_breaks
+
+A coderef for generating the breaks. 
+
+=head2 format
+
+A coderef that can be used for generating the break labels. 
+The default behavior is that if the breaks piddle consumes
+L<PDL::Role::HasNames> then its C<names()> method would be called to get
+the labels, otherwise the labels would be from the breaks values.
 
 =head1 AUTHOR
 
