@@ -4,9 +4,10 @@ package Chart::GGPlot::Trans::Functions;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use PDL::Math;
+use PDL::Primitive qw(which);
 use Role::Tiny ();
 
 use Chart::GGPlot::Trans;
@@ -17,7 +18,6 @@ use parent qw(Exporter::Tiny);
 
 our @EXPORT_OK = qw(
   is_trans as_trans trans_range
-  register_trans
   asn_trans      atanh_trans
   identity_trans log_trans
   log10_trans    log2_trans
@@ -30,11 +30,9 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 sub is_trans { $_[0]->$_isa('Chart::GGPlot::Trans'); }
 
 
-
-
 my %trans_registry = ();
 
-fun register_trans($trans) {
+fun _register_trans($trans) {
     $trans_registry{ $trans->name } = $trans;
 }
 
@@ -113,7 +111,8 @@ fun log_trans( $base = undef ) {
     $base //= exp(1);
     _trans_new( $name,
         fun($p) { $p->log / log($base) },
-        fun($p) { pdl($base) ** $p }
+        fun($p) { pdl($base) ** $p },
+        breaks => log_breaks($base),
     );
 }
 
@@ -199,7 +198,7 @@ for my $trans (
     time_trans(),
   )
 {
-    register_trans($trans);
+    _register_trans($trans);
 }
 
 1;
@@ -216,14 +215,16 @@ Chart::GGPlot::Trans::Functions - Function interface for Chart::GGPlot::Trans
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 FUNCTIONS
 
-=head2 register_trans($trans)
-
 =head2 as_trans($x)
 
+=head1 SEE ALSO
+
+L<Chart::GGPlot::Trans>
+
 =head1 AUTHOR
 
 Stephan Loyd <sloyd@cpan.org>
