@@ -4,7 +4,7 @@ package Chart::GGPlot::Util;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_02'; # TRIAL VERSION
+our $VERSION = '0.0002_01'; # TRIAL VERSION
 
 use Data::Dumper::Concise ();
 
@@ -16,6 +16,7 @@ use Data::Frame;
 use Math::Trig ();
 use constant PI => Math::Trig::pi;
 
+use List::AllUtils qw(min);
 use PDL::Primitive qw(which);
 use Package::Stash;
 use Types::PDL qw(Piddle1D PiddleFromAny);
@@ -44,6 +45,7 @@ my @export_all = (
       dist_euclidean dist_polar
       split_indices
       find_line_formula spiral_arc_length
+      has_groups
       ),
 );
 
@@ -246,12 +248,10 @@ fun spiral_arc_length ($a, $theta1, $theta2) {
 
 # Split indices of an indices array ref into groups
 # Return an arrayref of piddles.
-fun split_indices ((ArrayRef | Piddle1D) $indices, $n=List::AllUtils::max(@$indices)) {
-    my @rslt = map { [] } ( 0 .. $n - 1 );
+fun split_indices (Piddle1D $indices, $n=$indices->max) {
+    my @rslt = map { [] } ( 1 .. $n );
     for my $i ( 0 .. $indices->length - 1 ) {
-        my $id = $indices->at($i);
-        $id = $n if ( $id > $n );
-        $rslt[$id] //= [];
+        my $id = min($indices->at($i), $n);
         push @{ $rslt[$id] }, $i;
     }
     return [ map { pdl($_) } @rslt ];
@@ -272,6 +272,18 @@ fun resolution(Piddle1D $x, $zero=true) {
 
 fun stat($x) { $x }
 
+use constant NO_GROUP => -1;
+
+fun has_groups ($df) {
+
+    # If no group aesthetic is specified, all values of the group column
+    # equal to NO_GROUP. On the other hand, if a group aesthetic is
+    # specified, all values are different from NO_GROUP.
+    # undef is returned for 0-row data frames.
+    return undef if ( $df->nrow == 0 );
+    return ( $df->at('group')->at(0) >= 0 );
+}
+
 1;
 
 __END__
@@ -286,7 +298,7 @@ Chart::GGPlot::Util - Utility functions
 
 =head1 VERSION
 
-version 0.0000_02
+version 0.0002_01
 
 =head1 FUNCTIONS
 
